@@ -5,7 +5,7 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 import unittest
-from ..web.pyramid.locale import sorted_countries
+from bag.web.pyramid.locale import sorted_countries
 
 
 class TestLocale(unittest.TestCase):
